@@ -24,10 +24,9 @@
 #include <gtk/gtk.h>
 
 #include "vinagre-connection.h"
-#include "vinagre-enums.h"
 #include "vinagre-bookmarks.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
+#include "vinagre-utils.h"
 
 struct _VinagreConnectionPrivate
 {
@@ -183,11 +182,12 @@ static void
 default_fill_writer (VinagreConnection *conn, xmlTextWriter *writer)
 {
   if (conn->priv->protocol)
-    xmlTextWriterWriteElement (writer, "protocol", conn->priv->protocol);
-  xmlTextWriterWriteElement (writer, "name", conn->priv->name);
-  xmlTextWriterWriteElement (writer, "host", conn->priv->host);
-  xmlTextWriterWriteFormatElement (writer, "port", "%d", conn->priv->port);
-  xmlTextWriterWriteFormatElement (writer, "fullscreen", "%d", conn->priv->fullscreen);
+    xmlTextWriterWriteElement (writer, (const xmlChar *)"protocol", (const xmlChar *)conn->priv->protocol);
+  xmlTextWriterWriteElement (writer, (const xmlChar *)"name", (const xmlChar *)conn->priv->name);
+  xmlTextWriterWriteElement (writer, (const xmlChar *)"host", (const xmlChar *)conn->priv->host);
+  xmlTextWriterWriteElement (writer, (const xmlChar *)"username", (const xmlChar *) (conn->priv->username ? conn->priv->username : ""));
+  xmlTextWriterWriteFormatElement (writer, (const xmlChar *)"port", "%d", conn->priv->port);
+  xmlTextWriterWriteFormatElement (writer, (const xmlChar *)"fullscreen", "%d", conn->priv->fullscreen);
 }
 
 static void
@@ -201,13 +201,15 @@ default_parse_item (VinagreConnection *conn, xmlNode *root)
       s_value = xmlNodeGetContent (curr);
 
       if (!xmlStrcmp(curr->name, (const xmlChar *)"host"))
-	vinagre_connection_set_host (conn, s_value);
+	vinagre_connection_set_host (conn, (const gchar *)s_value);
       else if (!xmlStrcmp(curr->name, (const xmlChar *)"name"))
-	vinagre_connection_set_name (conn, s_value);
+	vinagre_connection_set_name (conn, (const gchar *)s_value);
+      else if (!xmlStrcmp(curr->name, (const xmlChar *)"username"))
+	vinagre_connection_set_username (conn, (const gchar *)s_value);
       else if (!xmlStrcmp(curr->name, (const xmlChar *)"port"))
-	vinagre_connection_set_port (conn, atoi (s_value));
+	vinagre_connection_set_port (conn, atoi ((const char *)s_value));
       else if (!xmlStrcmp(curr->name, (const xmlChar *)"fullscreen"))
-	vinagre_connection_set_fullscreen (conn, vinagre_utils_parse_boolean (s_value));
+	vinagre_connection_set_fullscreen (conn, vinagre_utils_parse_boolean ((const gchar *)s_value));
 
       xmlFree (s_value);
     }
@@ -286,7 +288,7 @@ vinagre_connection_class_init (VinagreConnectionClass *klass)
                                                       G_PARAM_STATIC_BLURB));
 
   g_object_class_install_property (object_class,
-                                   PROP_NAME,
+                                   PROP_USERNAME,
                                    g_param_spec_string ("username",
                                                         "username",
 	                                                "username (if any) necessary for complete this connection",
@@ -370,7 +372,10 @@ vinagre_connection_set_host (VinagreConnection *conn,
   g_return_if_fail (VINAGRE_IS_CONNECTION (conn));
 
   g_free (conn->priv->host);
-  conn->priv->host = g_strdup (host);
+  if (host)
+    conn->priv->host = g_strdup (g_strstrip ((gchar *)host));
+  else
+    conn->priv->host = NULL;
 }
 const gchar *
 vinagre_connection_get_host (VinagreConnection *conn)
@@ -398,7 +403,7 @@ vinagre_connection_get_port (VinagreConnection *conn)
 
 void
 vinagre_connection_set_username (VinagreConnection *conn,
-			     const gchar *username)
+				 const gchar *username)
 {
   g_return_if_fail (VINAGRE_IS_CONNECTION (conn));
 
@@ -488,7 +493,7 @@ vinagre_connection_split_string (const gchar *uri,
   gint    lport;
   gchar  *lhost;
   gchar   ipv6_host[255] = {0,};
-  VinagrePlugin *plugin;
+  VinagreProtocol *ext;
 
   *error_msg = NULL;
   *host = NULL;
@@ -512,9 +517,9 @@ vinagre_connection_split_string (const gchar *uri,
       lhost = (gchar *) uri;
     }
 
-  plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-							  *protocol);
-  if (!plugin)
+  ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+						       *protocol);
+  if (!ext)
     {
       *error_msg = g_strdup_printf (_("The protocol %s is not supported."), *protocol);
       g_free (*protocol);
@@ -538,12 +543,12 @@ vinagre_connection_split_string (const gchar *uri,
   if (g_strrstr (lhost, "::") != NULL)
     {
       server = g_strsplit (lhost, "::", 2);
-      lport = server[1] ? atoi (server[1]) : vinagre_plugin_get_default_port (plugin);
+      lport = server[1] ? atoi (server[1]) : vinagre_protocol_get_default_port (ext);
     }
   else
     {
       server = g_strsplit (lhost, ":", 2);
-      lport = server[1] ? atoi (server[1]) : vinagre_plugin_get_default_port (plugin);
+      lport = server[1] ? atoi (server[1]) : vinagre_protocol_get_default_port (ext);
 
       if ((g_str_equal (*protocol, "vnc")) && (lport < 1024))
         lport += 5900;
@@ -566,7 +571,7 @@ vinagre_connection_new_from_string (const gchar *uri, gchar **error_msg, gboolea
   VinagreConnection *conn = NULL;
   gint    port;
   gchar  *host, *protocol;
-  VinagrePlugin *plugin;
+  VinagreProtocol *ext;
 
   if (!vinagre_connection_split_string (uri, NULL, &protocol, &host, &port, error_msg))
     return NULL;
@@ -578,12 +583,12 @@ vinagre_connection_new_from_string (const gchar *uri, gchar **error_msg, gboolea
 				     port);
   if (!conn)
     {
-      plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-							      protocol);
-      if (!plugin)
+      ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+							   protocol);
+      if (!ext)
 	goto finalize;
 
-      conn = vinagre_plugin_new_connection (plugin);
+      conn = vinagre_protocol_new_connection (ext);
       vinagre_connection_set_host (conn, host);
       vinagre_connection_set_port (conn, port);
     }
@@ -601,9 +606,9 @@ vinagre_connection_new_from_file (const gchar *uri, gchar **error_msg, gboolean
   gchar             *data;
   GFile             *file_a;
   GError            *error;
-  GHashTable        *plugins;
+  GHashTable        *extensions;
   GHashTableIter     iter;
-  gpointer           plugin;
+  gpointer           ext;
 
   *error_msg = NULL;
   data = NULL;
@@ -629,14 +634,14 @@ vinagre_connection_new_from_file (const gchar *uri, gchar **error_msg, gboolean
       goto the_end;
     }
 
-  plugins = vinagre_plugin_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ());
-  g_hash_table_iter_init (&iter, plugins);
-  while (g_hash_table_iter_next (&iter, NULL, &plugin))
+  extensions = vinagre_plugins_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ());
+  g_hash_table_iter_init (&iter, extensions);
+  while (g_hash_table_iter_next (&iter, NULL, &ext))
     {
-      conn = vinagre_plugin_new_connection_from_file (VINAGRE_PLUGIN (plugin),
-						      data,
-						      use_bookmarks,
-						      error_msg);
+      conn = vinagre_protocol_new_connection_from_file ((VinagreProtocol *)ext,
+							data,
+							use_bookmarks,
+							error_msg);
       g_free (*error_msg);
       *error_msg = NULL;
       if (conn)
@@ -660,7 +665,7 @@ vinagre_connection_get_string_rep (VinagreConnection *conn,
   GString *uri;
   gchar *result;
   gboolean is_ipv6;
-  VinagrePlugin *plugin;
+  VinagreProtocol *ext;
 
   g_return_val_if_fail (VINAGRE_IS_CONNECTION (conn), NULL);
 
@@ -680,10 +685,9 @@ vinagre_connection_get_string_rep (VinagreConnection *conn,
   if (is_ipv6)
     g_string_append_c (uri, ']');
 
-  plugin = g_hash_table_lookup (vinagre_plugin_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ()),
-				conn->priv->protocol);
-  if (plugin)
-    if (vinagre_plugin_get_default_port (plugin) != conn->priv->port)
+  ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (), conn->priv->protocol);
+  if (ext)
+    if (vinagre_protocol_get_default_port (ext) != conn->priv->port)
       g_string_append_printf (uri, "::%d", conn->priv->port);
 
   result = uri->str;
@@ -694,8 +698,10 @@ vinagre_connection_get_string_rep (VinagreConnection *conn,
 
 void
 vinagre_connection_fill_writer (VinagreConnection *conn,
-				xmlTextWriter     *writer)
+				xmlTextWriterPtr   writer)
 {
+  g_return_if_fail (VINAGRE_IS_CONNECTION (conn));
+
   VINAGRE_CONNECTION_GET_CLASS (conn)->impl_fill_writer (conn, writer);
 }
 
@@ -703,12 +709,16 @@ void
 vinagre_connection_parse_item (VinagreConnection *conn,
 			       xmlNode           *root)
 {
+  g_return_if_fail (VINAGRE_IS_CONNECTION (conn));
+
   VINAGRE_CONNECTION_GET_CLASS (conn)->impl_parse_item (conn, root);
 }
 
 gchar*
 vinagre_connection_get_best_name (VinagreConnection *conn)
 {
+  g_return_val_if_fail (VINAGRE_IS_CONNECTION (conn), NULL);
+
   return VINAGRE_CONNECTION_GET_CLASS (conn)->impl_get_best_name (conn);
 }
 
